@@ -167,7 +167,6 @@ static auto serializeDataExtension(const DataExtension &ext, QXmlStreamWriter &w
 
 void tst_QXmppAccountMigrationManager::testImportExport()
 {
-
     QXmppExportData::registerExtension<DataExtension, parseDataExtension, serializeDataExtension>(u"extension", u"org.qxmpp.tests");
 
     auto client = newClient(false);
@@ -351,45 +350,48 @@ void tst_QXmppAccountMigrationManager::testSerialization()
     auto exportTask = manager->exportData();
     QVERIFY(!exportTask.isFinished());
 
-    client->expect(u"<iq id='qxmpp2' from='pasnox@xmpp.example/QXmpp' type='get'>"
+    client->expect(u"<iq id='qx2' from='pasnox@xmpp.example/QXmpp' type='get'>"
                    "<query xmlns='jabber:iq:roster'>"
                    "<annotate xmlns='urn:xmpp:mix:roster:0'/>"
                    "</query>"
                    "</iq>"_s);
-    client->inject(packetToXml(newRoster(client.get(), 1, "qxmpp2", QXmppIq::Result)));
+    client->inject(packetToXml(newRoster(client.get(), 1, "qx2", QXmppIq::Result)));
 
-    client->expect(u"<iq id='qxmpp3' from='pasnox@xmpp.example/QXmpp' type='get'>"
+    client->expect(u"<iq id='qx3' from='pasnox@xmpp.example/QXmpp' type='get'>"
                    "<query xmlns='jabber:iq:roster'>"
                    "<annotate xmlns='urn:xmpp:mix:roster:0'/>"
                    "</query>"
                    "</iq>"_s);
-    client->inject(packetToXml(newRoster(client.get(), 1, "qxmpp3", QXmppIq::Result)));
+    client->inject(packetToXml(newRoster(client.get(), 1, "qx3", QXmppIq::Result)));
 
-    client->expect(u"<iq id='qxmpp4' to='pasnox@xmpp.example' type='get'>"
+    client->expect(u"<iq id='qx4' to='pasnox@xmpp.example' type='get'>"
                    "<vCard xmlns='vcard-temp'>"
                    "<TITLE/>"
                    "<ROLE/>"
                    "</vCard>"
                    "</iq>"_s);
-    client->inject(packetToXml(newClientVCard(client.get(), 1, "qxmpp4", QXmppIq::Result)));
+    client->inject(packetToXml(newClientVCard(client.get(), 1, "qx4", QXmppIq::Result)));
 
-    client->expect(u"<iq id='qxmpp7' to='mix2@gamer.com' type='get'>"
-                   "<pubsub xmlns='http://jabber.org/protocol/pubsub'>"
-                   "<items node='urn:xmpp:mix:nodes:participants'/>"
-                   "</pubsub>"
-                   "</iq>"_s);
-    client->inject(u"<iq id='qxmpp7' from='mix2@gamer.com' type='result'>"
-                   "<pubsub xmlns='http://jabber.org/protocol/pubsub'>"
-                   "<items node='urn:xmpp:mix:nodes:participants'>"
-                   "<item id='mix2BareId'>"
-                   "<participant xmlns='urn:xmpp:mix:core:1'>"
-                   "<nick>Joe @ Mix 2 Gamer</nick>"
-                   "<jid>mix_user@domain.ext</jid>"
-                   "</participant>"
-                   "</item>"
-                   "</items>"
-                   "</pubsub>"
-                   "</iq>"_s);
+    auto packetId = client->expectPacketRandomOrder(
+        u"<iq to='mix2@gamer.com' type='get'>"
+        "<pubsub xmlns='http://jabber.org/protocol/pubsub'>"
+        "<items node='urn:xmpp:mix:nodes:participants'/>"
+        "</pubsub>"
+        "</iq>"_s);
+    client->inject(
+        u"<iq id='%1' from='mix2@gamer.com' type='result'>"
+        "<pubsub xmlns='http://jabber.org/protocol/pubsub'>"
+        "<items node='urn:xmpp:mix:nodes:participants'>"
+        "<item id='mix2BareId'>"
+        "<participant xmlns='urn:xmpp:mix:core:1'>"
+        "<nick>Joe @ Mix 2 Gamer</nick>"
+        "<jid>mix_user@domain.ext</jid>"
+        "</participant>"
+        "</item>"
+        "</items>"
+        "</pubsub>"
+        "</iq>"_s
+            .arg(packetId));
 
     client->expectNoPacket();
 
@@ -426,31 +428,30 @@ void tst_QXmppAccountMigrationManager::testSerialization()
     // test parse (and re-serialize)
     auto parsedData = expectVariant<QXmppExportData>(QXmppExportData::fromDom(xmlToDom(xml2)));
     const auto xml3 = packetToXml(parsedData);
-    const QByteArray xml4 =
-        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
-        "<account-data xmlns=\"org.qxmpp.export\" jid=\"pasnox@xmpp.example\">"
+    const QByteArray xml4Mix =
         "<mix>"
         "<item jid=\"mix2@gamer.com\" nick=\"Joe @ Mix 2 Gamer\"/>"
-        "</mix>"
-        "<roster>"
-        "<item xmlns=\"jabber:iq:roster\" jid=\"3@gamer.com\" name=\"3 Gamer\"><group>gamers</group></item>"
-        "</roster>"
+        "</mix>";
+    const QByteArray xml4VCard =
         "<vcard>"
         "<vCard xmlns=\"vcard-temp\">"
         "<NICKNAME>It is me Bookri</NICKNAME>"
         "<N><GIVEN>Nox</GIVEN><FAMILY>Bookri</FAMILY></N>"
         "<TITLE/><ROLE/>"
         "</vCard>"
-        "</vcard>"
-        "</account-data>\n";
+        "</vcard>";
+    const QByteArray xml4Roster =
+        "<roster>"
+        "<item xmlns=\"jabber:iq:roster\" jid=\"3@gamer.com\" name=\"3 Gamer\"><group>gamers</group></item>"
+        "</roster>";
 
-    if (xml3 != xml4) {
-        qDebug() << "Actual:\n"
-                 << xml3.constData();
-        qDebug() << "Expected:\n"
-                 << xml4.constData();
-    }
-    QCOMPARE(xml3, xml4);
+    QVERIFY(xml3.startsWith(
+        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
+        "<account-data xmlns=\"org.qxmpp.export\" jid=\"pasnox@xmpp.example\">"));
+    QVERIFY(xml3.endsWith("</account-data>\n"));
+    QVERIFY(xml3.contains(xml4Mix));
+    QVERIFY(xml3.contains(xml4Roster));
+    QVERIFY(xml3.contains(xml4VCard));
 }
 
 QTEST_MAIN(tst_QXmppAccountMigrationManager)
