@@ -53,6 +53,7 @@ private:
     Q_SLOT void testProcessingHints();
     Q_SLOT void testBobData();
     Q_SLOT void testFallbackIndication();
+    Q_SLOT void fallbackBodies();
     Q_SLOT void testStanzaIds();
     Q_SLOT void testSlashMe_data();
     Q_SLOT void testSlashMe();
@@ -62,6 +63,7 @@ private:
     Q_SLOT void testE2eeFallbackBody();
     Q_SLOT void testFileSharing();
     Q_SLOT void testEncryptedFileSource();
+    Q_SLOT void testReplies();
     Q_SLOT void testJingleMessageInitiationElement();
 };
 
@@ -307,13 +309,13 @@ void tst_QXmppMessage::testDelay_data()
         << QByteArray("<message type=\"normal\">"
                       "<delay xmlns=\"urn:xmpp:delay\" stamp=\"2010-06-29T08:23:06Z\"/>"
                       "</message>")
-        << QDateTime(QDate(2010, 06, 29), QTime(8, 23, 6), Qt::UTC);
+        << QDateTime(QDate(2010, 06, 29), QTime(8, 23, 6), TimeZoneUTC);
 
     QTest::newRow("legacy")
         << QByteArray("<message type=\"normal\">"
                       "<x xmlns=\"jabber:x:delay\" stamp=\"20100629T08:23:06\"/>"
                       "</message>")
-        << QDateTime(QDate(2010, 06, 29), QTime(8, 23, 6), Qt::UTC);
+        << QDateTime(QDate(2010, 06, 29), QTime(8, 23, 6), TimeZoneUTC);
 }
 
 void tst_QXmppMessage::testDelay()
@@ -343,7 +345,7 @@ void tst_QXmppMessage::testDelayWithMultipleStamp()
     QXmppMessage message;
     parsePacket(message, xml);
     qDebug() << message.stamp();
-    QCOMPARE(message.stamp(), QDateTime(QDate(2010, 06, 29), QTime(8, 23, 6, 123), Qt::UTC));
+    QCOMPARE(message.stamp(), QDateTime(QDate(2010, 06, 29), QTime(8, 23, 6, 123), TimeZoneUTC));
     serializePacket(message, resultXml);
 }
 
@@ -463,9 +465,9 @@ void tst_QXmppMessage::testSubextensions()
 {
     const QByteArray xml = QByteArrayLiteral(
         "<message id=\"aeb214\" to=\"juliet@capulet.lit/chamber\" type=\"normal\">"
-        "<result xmlns=\"urn:xmpp:mam:tmp\" id=\"5d398-28273-f7382\" queryid=\"f27\">"
+        "<result id=\"5d398-28273-f7382\" queryid=\"f27\" xmlns=\"urn:xmpp:mam:tmp\">"
         "<forwarded xmlns=\"urn:xmpp:forward:0\">"
-        "<delay xmlns=\"urn:xmpp:delay\" stamp=\"2010-07-10T23:09:32Z\"/>"
+        "<delay stamp=\"2010-07-10T23:09:32Z\" xmlns=\"urn:xmpp:delay\"/>"
         "<message from=\"juliet@capulet.lit/balcony\" "
         "id=\"8a54s\" "
         "to=\"romeo@montague.lit/orchard\" "
@@ -869,7 +871,7 @@ void tst_QXmppMessage::testSpoiler()
     const QByteArray xmlWithoutHint(
         "<message to=\"foo@example.com/QXmpp\" from=\"bar@example.com/QXmpp\" type=\"normal\">"
         "<body>And at the end of the story, both of them die! It is so tragic!</body>"
-        "<spoiler xmlns=\"urn:xmpp:spoiler:0\"></spoiler>"
+        "<spoiler xmlns=\"urn:xmpp:spoiler:0\"/>"
         "</message>");
 
     QXmppMessage messageWithoutHint;
@@ -1078,12 +1080,39 @@ void tst_QXmppMessage::testFallbackIndication()
             "urn:xmpp:reply:0",
             { Fallback::Reference { Fallback::Body, Fallback::Range { 0, 33 } },
               Fallback::Reference { Fallback::Subject, Fallback::Range { 5, 10 } },
-              Fallback::Reference { Fallback::Body, {} } },
+              Fallback::Reference { Fallback::Body, std::nullopt } },
         },
     });
     serializePacket(message, xml);
 }
 
+void tst_QXmppMessage::fallbackBodies()
+{
+    const QByteArray xml = QByteArrayLiteral(
+        "<message to='anna@example.com' id='message-id2' type='groupchat'>"
+        "<body>"
+        "> Anna wrote:\n"
+        "> Hi, how are you?\n"
+        "Great"
+        "</body>"
+        "<reply to='anna@example.com' id='message-id1' xmlns='urn:xmpp:reply:0'/>"
+        "<fallback xmlns='urn:xmpp:fallback:0' for='urn:xmpp:reply:0'>"
+        "<body start='0' end='33' />"
+        "</fallback>"
+        "</message>");
+
+    QXmppMessage message;
+    parsePacket(message, xml);
+
+    QCOMPARE(message.readFallbackRemovedText(QXmppFallback::Body, { "urn:xmpp:reply:0" }), "Great");
+    QCOMPARE(message.readFallbackRemovedText(QXmppFallback::Subject, { "urn:xmpp:reply:0" }), QString());
+
+    QCOMPARE(message.readFallbackText(QXmppFallback::Body, u"urn:xmpp:reply:0"), "> Anna wrote:\n> Hi, how are you?\n");
+    QCOMPARE(message.readFallbackText(QXmppFallback::Subject, u"urn:xmpp:reply:0"), QString());
+
+    QCOMPARE(message.readReplyQuoteFromBody(), "Anna wrote:\nHi, how are you?\n");
+}
+
 void tst_QXmppMessage::testStanzaIds()
 {
     const QByteArray xml = QByteArrayLiteral(
@@ -1313,13 +1342,13 @@ void tst_QXmppMessage::testFileSharing()
     serializePacket(message, xml);
 
     xml = "<message id='adding-photo1' to='juliet@shakespeare.lit' from='romeo@montague.lit/resource' type='normal'>"
-          "<fallback xmlns='urn:xmpp:fallback:0' for='urn:xmpp:sfs:0'><body/></fallback>"
           "<body>https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/photo1.jpg</body>"
           "<x xmlns='jabber:x:oob'><url>https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/photo1.jpg</url></x>"
           "<attach-to xmlns='urn:xmpp:message-attaching:1' id='sharing-files'/>"
           "<sources xmlns='urn:xmpp:sfs:0' id='photo1.jpg'>"
           "<url-data xmlns='http://jabber.org/protocol/url-data' target='https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/photo1.jpg'/>"
           "</sources>"
+          "<fallback xmlns='urn:xmpp:fallback:0' for='urn:xmpp:sfs:0'><body/></fallback>"
           "</message>";
     message = {};
 
@@ -1391,6 +1420,22 @@ void tst_QXmppMessage::testEncryptedFileSource()
     }
 }
 
+void tst_QXmppMessage::testReplies()
+{
+    const QByteArray xml =
+        "<message id='message-id2' to='anna@example.com' type='chat'>"
+        "<body>Great idea!</body>"
+        "<reply xmlns='urn:xmpp:reply:0' to='anna@example.com/tablet' id='message-id1'/>"
+        "</message>";
+
+    QXmppMessage m;
+    parsePacket(m, xml);
+    QVERIFY(m.reply().has_value());
+    QCOMPARE(m.reply()->id, "message-id1");
+    QCOMPARE(m.reply()->to, "anna@example.com/tablet");
+    serializePacket(m, xml);
+}
+
 void tst_QXmppMessage::testJingleMessageInitiationElement()
 {
     const QByteArray xml(
