@@ -118,7 +118,7 @@ void tst_QXmppMixItem::testConfig()
     QCOMPARE(item1.lastEditorJid(), u"greymalkin@shakespeare.example"_s);
     QCOMPARE(item1.ownerJids(), QStringList({ u"hecate@shakespeare.example"_s, u"greymalkin@shakespeare.example"_s }));
     QCOMPARE(item1.administratorJids(), QStringList({ u"juliet@shakespeare.example"_s, u"romeo@shakespeare.example"_s }));
-    QCOMPARE(item1.channelDeletion(), QDateTime({ { 2023, 12, 31 }, { 12, 30 }, Qt::UTC }));
+    QCOMPARE(item1.channelDeletion(), QDateTime({ { 2023, 12, 31 }, { 12, 30 }, TimeZoneUTC }));
     QCOMPARE(item1.nodes(), QXmppMixConfigItem::Node::AllowedJids | QXmppMixConfigItem::Node::Information);
     QCOMPARE(item1.messagesSubscribeRole(), QXmppMixConfigItem::Role::Allowed);
     QCOMPARE(item1.messagesRetractRole(), QXmppMixConfigItem::Role::Nobody);
@@ -152,7 +152,7 @@ void tst_QXmppMixItem::testConfig()
                                      u"greymalkin@shakespeare.example"_s }));
     item2.setAdministratorJids(QStringList({ u"juliet@shakespeare.example"_s,
                                              u"romeo@shakespeare.example"_s }));
-    item2.setChannelDeletion({ { 2023, 12, 31 }, { 12, 30 }, Qt::UTC });
+    item2.setChannelDeletion({ { 2023, 12, 31 }, { 12, 30 }, TimeZoneUTC });
     item2.setNodes(QXmppMixConfigItem::Node::AllowedJids | QXmppMixConfigItem::Node::Information);
     item2.setMessagesSubscribeRole(QXmppMixConfigItem::Role::Allowed);
     item2.setMessagesRetractRole(QXmppMixConfigItem::Role::Nobody);
@@ -175,7 +175,7 @@ void tst_QXmppMixItem::testConfig()
     QCOMPARE(item2.lastEditorJid(), u"greymalkin@shakespeare.example"_s);
     QCOMPARE(item2.ownerJids(), QStringList({ u"hecate@shakespeare.example"_s, u"greymalkin@shakespeare.example"_s }));
     QCOMPARE(item2.administratorJids(), QStringList({ u"juliet@shakespeare.example"_s, u"romeo@shakespeare.example"_s }));
-    QCOMPARE(item2.channelDeletion(), QDateTime({ { 2023, 12, 31 }, { 12, 30 }, Qt::UTC }));
+    QCOMPARE(item2.channelDeletion(), QDateTime({ { 2023, 12, 31 }, { 12, 30 }, TimeZoneUTC }));
     QCOMPARE(item2.nodes(), QXmppMixConfigItem::Node::AllowedJids | QXmppMixConfigItem::Node::Information);
     QCOMPARE(item2.messagesSubscribeRole(), QXmppMixConfigItem::Role::Allowed);
     QCOMPARE(item2.messagesRetractRole(), QXmppMixConfigItem::Role::Nobody);
@@ -204,9 +204,6 @@ void tst_QXmppMixItem::testConfig()
 
 void tst_QXmppMixItem::testIsConfigItem()
 {
-    QDomDocument doc;
-    QDomElement element;
-
     const QByteArray xmlCorrect(
         "<item>"
         "<x xmlns=\"jabber:x:data\" type=\"result\">"
@@ -215,9 +212,7 @@ void tst_QXmppMixItem::testIsConfigItem()
         "</field>"
         "</x>"
         "</item>");
-    QVERIFY(doc.setContent(xmlCorrect, true));
-    element = doc.documentElement();
-    QVERIFY(QXmppMixConfigItem::isItem(element));
+    QVERIFY(QXmppMixConfigItem::isItem(xmlToDom(xmlCorrect)));
 
     const QByteArray xmlWrong(
         "<item>"
@@ -227,9 +222,7 @@ void tst_QXmppMixItem::testIsConfigItem()
         "</field>"
         "</x>"
         "</item>");
-    QVERIFY(doc.setContent(xmlWrong, true));
-    element = doc.documentElement();
-    QVERIFY(!QXmppMixConfigItem::isItem(element));
+    QVERIFY(!QXmppMixConfigItem::isItem(xmlToDom(xmlWrong)));
 }
 
 void tst_QXmppMixItem::testInfo()
@@ -282,9 +275,6 @@ void tst_QXmppMixItem::testInfo()
 
 void tst_QXmppMixItem::testIsInfoItem()
 {
-    QDomDocument doc;
-    QDomElement element;
-
     const QByteArray xmlCorrect(
         "<item>"
         "<x xmlns=\"jabber:x:data\" type=\"result\">"
@@ -293,9 +283,7 @@ void tst_QXmppMixItem::testIsInfoItem()
         "</field>"
         "</x>"
         "</item>");
-    QVERIFY(doc.setContent(xmlCorrect, true));
-    element = doc.documentElement();
-    QVERIFY(QXmppMixInfoItem::isItem(element));
+    QVERIFY(QXmppMixInfoItem::isItem(xmlToDom(xmlCorrect)));
 
     const QByteArray xmlWrong(
         "<item>"
@@ -305,9 +293,7 @@ void tst_QXmppMixItem::testIsInfoItem()
         "</field>"
         "</x>"
         "</item>");
-    QVERIFY(doc.setContent(xmlWrong, true));
-    element = doc.documentElement();
-    QVERIFY(!QXmppMixInfoItem::isItem(element));
+    QVERIFY(!QXmppMixInfoItem::isItem(xmlToDom(xmlWrong)));
 }
 
 void tst_QXmppMixItem::testParticipant()
@@ -338,26 +324,19 @@ void tst_QXmppMixItem::testParticipant()
 
 void tst_QXmppMixItem::testIsParticipantItem()
 {
-    QDomDocument doc;
-    QDomElement element;
-
     const QByteArray xmlCorrect(
         "<item>"
         "<participant xmlns=\"urn:xmpp:mix:core:1\">"
         "</participant>"
         "</item>");
-    QVERIFY(doc.setContent(xmlCorrect, true));
-    element = doc.documentElement();
-    QVERIFY(QXmppMixParticipantItem::isItem(element));
+    QVERIFY(QXmppMixParticipantItem::isItem(xmlToDom(xmlCorrect)));
 
     const QByteArray xmlWrong(
         "<item>"
         "<participant xmlns=\"other:namespace:1\">"
         "</participant>"
         "</item>");
-    QVERIFY(doc.setContent(xmlWrong, true));
-    element = doc.documentElement();
-    QVERIFY(!QXmppMixParticipantItem::isItem(element));
+    QVERIFY(!QXmppMixParticipantItem::isItem(xmlToDom(xmlWrong)));
 }
 
 QTEST_MAIN(tst_QXmppMixItem)
